'use strict'

const fs = require('fs')
const inquirer = require('inquirer');
const Handlebars = require("handlebars");
const download = require("download-git-repo");
const path = require("path");
const rimraf = require("rimraf");
const ora = require('ora')
const chalk = require('chalk')
const template = require('../template.json')

const promptList = [
    {
        type: 'list',
        message: '请选择技术栈 :',
        name: 'technologyStack',
        choices: [
            "Vue",
            "React",
        ],
        default:'vue'
    },
    {
        type: 'list',
        message: 'PC or H5 :',
        name: 'platform',
        choices: [
            "pc",
            "h5",
        ],
        default:'pc'
    }];

const templateType = [
    {
        type: 'list',
        message: '请选择使用自定义模版或者公共模版 :',
        name: 'templateType',
        choices: [
            "default",
            "custom",
        ],
        default:'default'
    }
]

let templateList = []

for (let i in template){
    templateList.push(i)
}

const promptLemplateList = [
    {
        type: 'list',
        message: '请选择模版 :',
        name: 'name',
        choices: templateList,
        default:'vue-pc'
    }
]
module.exports = (name)=>{
    inquirer.prompt(templateType).then(res=>{
        const dir = path.join(process.cwd(), name); //这里可以自定义下载的地址

        let data = res.templateType == 'default' ? promptList : promptLemplateList
        inquirer.prompt(data).then(answers => {
            let gitUrl = res.templateType == 'default' ? template[answers.technologyStack+'-'+answers.platform]:template[answers.name]
            rimraf.sync(dir, {}, () => {

            });  //在下载前需要保证路径下没有同名文件

            const param = {name}
            const spinner = ora('正在下载模板, 请稍后...');
            spinner.start()

            download(gitUrl.url, dir,
                {},
                function (error) {
                    if (!error) {
                        spinner.succeed();
                        const packagePath = path.join(dir, 'package.json');// 判断是否有package.json, 要把输入的数据回填到模板中
                        if (fs.existsSync(packagePath)) {
                            const content = fs.readFileSync(packagePath).toString();
                            // handlebars 模板处理引擎
                            const template = Handlebars.compile(content);
                            const result = template(param);
                            fs.writeFileSync(packagePath, result);
                            console.log(chalk.green('success! 项目初始化成功！'));
                            console.log(chalk.greenBright('开启项目') +'\n'+ chalk.greenBright('cd '+ name) +'\n'+ chalk.greenBright('start to dvelop~~~!') )

                        } else {
                            spinner.fail();
                            console.log(chalk.red('failed! no package.json'));
                            return;
                        }
                    } else {
                        console.log(chalk.red('failed! 拉取模板失败', error));
                        return;
                    }
                })
        })
    })
}
